<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
		xmlns:sdf="java.text.SimpleDateFormat"
        	xmlns:date="java.util.Date">
    
    <xsl:include href="footer.xsl"/>

    <xsl:template match="/">
        <head>
            <link href="css/inca.css" rel="stylesheet" type="text/css" />
        </head>
        <body>
            <xsl:choose>
                <xsl:when test="count(//error)&gt;0">
                    <i>The following error occured:</i>
                    <xsl:for-each select="//error">
                        <h3>
                            <xsl:value-of select="." />
                        </h3>
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="printResults" />
                    <xsl:call-template name="footer" />
                </xsl:otherwise>
            </xsl:choose>
        </body>
    </xsl:template>

    <xsl:template name="printResults">
        <h1 class="body">
          <xsl:value-of select="'configured inca reporters'" />
        </h1>
	<xsl:variable name="datenow" select="date:new()" />
  	<xsl:variable name="dateformat" select="sdf:new('MM-dd-yyyy hh:mm a (z)')" />
	<p class="footer">Page loaded: <xsl:value-of select="sdf:format($dateformat, $datenow)" /></p>
  	<xsl:variable name="cat" select="combo/catalogs/catalog" />
        <table cellpadding="6" class="subheader">
          <xsl:for-each select="combo/suites//suite">
            <xsl:sort select="." />
            <xsl:variable name="numSeries" select="count(seriesConfigs//seriesConfig)"/>
            <tr valign="top">
              <td class="header">
                <xsl:value-of select="name"/>
              </td>
              <td class="header">
                <xsl:value-of select="'('"/>
                <xsl:value-of select="$numSeries"/>
                <xsl:value-of select="' reporter series described)'"/>
              </td>
            </tr>
            <xsl:for-each select="seriesConfigs//seriesConfig">
              <xsl:sort select="nickname" />
              <xsl:variable name="repname" select="series/name"/>
              <xsl:variable name="uri" select="series/uri"/>
              <xsl:variable name="repository" select="substring-before($uri, $repname)"/>
              <xsl:variable name="rep-cgi">
                <xsl:value-of select="$repository"/>
                <xsl:value-of select="'../cgi-bin/reporters.cgi?reporter='"/>
                <xsl:value-of select="$repname"/>
                <xsl:value-of select="'&amp;action=help'"/>
              </xsl:variable>
              <xsl:variable name="desc">
                <xsl:for-each select="$cat//reporter">
		  <xsl:if test="property[matches(value, $repname)]">
	            <xsl:value-of select="property[matches(name, 'description')]/value"/>
		  </xsl:if>
                </xsl:for-each>
              </xsl:variable>
              <tr valign="top">
                  <td class="clear">
                    <a href="{$rep-cgi}"><xsl:value-of select="nickname" /></a>
                  </td>
                  <td class="clear"><xsl:value-of select="$desc"/></td>
                </tr>
            </xsl:for-each>
          </xsl:for-each>
        </table>
    </xsl:template>

</xsl:stylesheet>
