<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
		xmlns:sdf="java.text.SimpleDateFormat"
        	xmlns:date="java.util.Date"
		xmlns:xdt="http://www.w3.org/2004/07/xpath-datatypes"
		xmlns:xs="http://www.w3.org/2001/XMLSchema">
    
    <xsl:include href="footer.xsl"/>
    <xsl:param name="url" />

    <xsl:template match="/">
        <head>
            <link href="css/inca.css" rel="stylesheet" type="text/css" />
        </head>
        <body>
            <xsl:choose>
                <xsl:when test="count(//error)&gt;0">
                    <i>The following error occured:</i>
                    <xsl:for-each select="//error">
                        <h3>
                            <xsl:value-of select="." />
                        </h3>
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="printResults" />
                    <xsl:call-template name="footer" />
                </xsl:otherwise>
            </xsl:choose>
        </body>
    </xsl:template>

    <xsl:template name="printResults">
        <h1 class="body">
		<xsl:value-of select="combo/stack/id" />
		<xsl:value-of select="' (summary)'" />
	</h1>
	<xsl:variable name="datenow" select="date:new()" />
  	<xsl:variable name="dateformat" select="sdf:new('MM-dd-yyyy hh:mm a (z)')" />
	<p class="footer">Page loaded: <xsl:value-of select="sdf:format($dateformat, $datenow)" /></p>
        <xsl:call-template name="printResourceListTable" />
        <xsl:call-template name="printSummaryTable" />
    </xsl:template>

    <xsl:template name="printResourceListTable">
        <!-- print table with list of resources, four resources in a col -->
        <table cellpadding="8">
            <tr valign="top">
                <td>
                    <xsl:for-each select="combo/resourceConfig/resources//resource">
                        <xsl:sort/>
                            <xsl:variable name="anc">
                                <xsl:value-of select="'#'" />
                                <xsl:value-of select="name" />
                            </xsl:variable>
                            <xsl:if test="position() mod 4 = 1">
                                <td />
                            </xsl:if>
                            <li>
                                <a href="{$anc}"> <xsl:value-of select="name" /></a>
                            </li>
                    </xsl:for-each>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="printSummaryTable">
        <xsl:variable name="alltests" select="//stack//package//tests" />
        <xsl:variable name="crosstests" select="$alltests/unitalias[matches(id, '^all2all:.*$')]/id"/>
        <xsl:variable name="unittests" select="$alltests/unitalias[not(matches(id, '^all2all:.*$'))]/id"/>
        <xsl:variable name="vertests" select="$alltests/version/id"/>
	<hr/>
	<p>
		<xsl:value-of select="count($crosstests) + count($unittests) + count($vertests)" />
		<xsl:value-of select="' possible tests ('" />
		<xsl:value-of select="count($unittests)" />
		<xsl:value-of select="' unit, '" />
		<xsl:value-of select="count($vertests)" />
		<xsl:value-of select="' version, '" />
		<xsl:value-of select="count($crosstests)" />
		<xsl:value-of select="' cross-site)'" />
	</p>
        <table cellpadding="8" class="subheader">
            <xsl:for-each select="combo/resourceConfig/resources//resource">
                <xsl:sort/>
                <xsl:variable name="regexHost">
                    <xsl:value-of select="name" />
                    <xsl:value-of select="'|'" />
                    <xsl:value-of select="replace(macros/macro[name='__regexp__']/value, ' ','|')"/>
                </xsl:variable>
		<!-- get unit test stats -->
                <xsl:variable name="unitMatch" select="//reportSummary[matches(hostname, $regexHost)]//nickname[.=$unittests]" />
                <xsl:variable name="numUnitMatches" select="count($unitMatch)" />
                <xsl:variable name="unitCompleted" select="$unitMatch/../body" />
                <xsl:variable name="unitFail" select="count($unitCompleted[.=''])" />
                <xsl:variable name="numUnitFail" select="if (number($unitFail)=number($unitFail)) then $unitFail else 0" />
                <xsl:variable name="unitPass" select="count($unitCompleted[.!=''])" />
                <xsl:variable name="numUnitPass" select="if (number($unitPass)=number($unitPass)) then $unitPass else 0" />
                <xsl:variable name="numUnitMiss" select="$numUnitMatches - $numUnitFail - $numUnitPass" />
                <xsl:variable name="unitMissing" select="$unitMatch[not(.=$unitCompleted/../nickname)]" />
		<!-- get version test stats -->
		<xsl:variable name="verMatch" select="//reportSummary[matches(hostname, $regexHost)]//nickname[. = $vertests]" />
                <xsl:variable name="numVerMatches" select="count($verMatch)" />
                <xsl:variable name="verCompleted" select="$verMatch/../comparisonResult" />
                <xsl:variable name="verFail" select="count($verCompleted[.!='Success'])" />
                <xsl:variable name="numVerFail" select="if (number($verFail)=number($verFail)) then $verFail else 0" />
                <xsl:variable name="verPass" select="count($verCompleted[.='Success'])" />
                <xsl:variable name="numVerPass" select="if (number($verPass)=number($verPass)) then $verPass else 0" />
                <xsl:variable name="numVerMiss" select="$numVerMatches - $numVerFail - $numVerPass" />
                <xsl:variable name="verMissing" select="$verMatch[not(.=$verCompleted/../nickname)]" />
		<!-- get cross-site test stats -->
                <xsl:variable name="crossMatch" select="//reportSummary[matches(hostname, $regexHost)]//nickname[.=$crosstests]" />
                <xsl:variable name="numCrossMatches" select="count($crossMatch)" />
                <xsl:variable name="crossCompleted" select="$crossMatch/../body" />
                <xsl:variable name="crossMissing" select="$crossMatch[not(.=$crossCompleted/../nickname)]" />
                <xsl:variable name="numCrossMiss" select="count($crossMissing)" />
		<xsl:variable name="crossFail" select="//resource[matches(name, $regexHost)]/testSummaries//testSummary/failures//failure" />
		<!-- get total stats -->
		<xsl:variable name="numUnitVersionFail" select="$numUnitFail + $numVerFail" />
		<xsl:variable name="numCrossFail" select="count($crossFail)" />
		<xsl:variable name="unitVersionFail" select="$unitCompleted[.='']/../nickname | $verCompleted[.!='Success']/../nickname" />
		<xsl:variable name="allMissing" select="$verMissing | $unitMissing | $crossMissing" />
		<xsl:variable name="numAllMatches" select="$numVerMatches + $numUnitMatches + $numCrossMatches" />
		<xsl:variable name="numAllMiss" select="$numUnitMiss + $numVerMiss + $numCrossMiss" />
		<xsl:variable name="numAllMiss" select="$numUnitMiss + $numVerMiss + $numCrossMiss" />
		<xsl:variable name="numAllFail" select="$numUnitVersionFail + $numCrossFail" />
                <xsl:variable name="percPass">
			<xsl:choose>
				<xsl:when test="$numUnitVersionFail=0">
					<xsl:value-of select="100"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of  select="100 - round($numAllFail div $numAllMatches * 100)" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="color">
		    <xsl:choose>
			<xsl:when test="$percPass=100">
				<xsl:value-of select="'pass'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'fail'"/>
			</xsl:otherwise>
		    </xsl:choose>
		</xsl:variable>
                <tr>
                    <td class="clear" valign="top">
                	<xsl:element name="a">
                    		<xsl:attribute name="name">
                        		<xsl:value-of select="name" />
                    		</xsl:attribute>
                	</xsl:element>
                        <xsl:value-of select="name" />
                    </td>
                    <td class="clear" valign="top">
                        <xsl:value-of select="$percPass" />
                        <xsl:value-of select="'% passed'" />
			<br/><br/>
			<u><b><xsl:value-of select="'Tests:'" /></b></u>
			<xsl:value-of select="' '" />
			<xsl:value-of select="$numAllMatches" /><br/>
			<xsl:value-of select="' ('" />
			<xsl:value-of select="$numUnitMatches" />
			<xsl:value-of select="' unit, '" />
			<xsl:value-of select="$numVerMatches" />
			<xsl:value-of select="' version, '" />
			<xsl:value-of select="$numCrossMatches" />
			<xsl:value-of select="' cross-site)'" />
			<br/><br/>
                        <xsl:if test="$numUnitVersionFail>0">
				<xsl:variable name="core" select="//stack/category[id='core']//package/tests" />
				<xsl:variable name="coreTests" select="$core/version/id | $core//unitalias/id" />
				<u><b><xsl:value-of select="'Errors:'" /></b></u>
					<xsl:value-of select="' '" />
					<xsl:value-of select="$numAllFail" /><br/>
					<xsl:value-of select="' ('" />
					<xsl:value-of select="$numUnitVersionFail" />
					<xsl:value-of select="' unit/version)'" />
				<ol><xsl:for-each select="$unitVersionFail">
					<xsl:sort select="."/>
                                    	<xsl:variable name="thisTest" select="." />
					<xsl:variable name="result" select="//reportSummary[matches(hostname, $regexHost) and nickname=$thisTest]" />
                			<xsl:variable name="instance" select="$result/instanceId" />
                			<xsl:variable name="conf" select="$result/seriesConfigId" />
                        		<xsl:variable name="href">
                            			<xsl:value-of select="'xslt.jsp?xsl=instance.xsl&amp;instanceID='" />
                            			<xsl:value-of select="$instance" />
                            			<xsl:value-of select="'&amp;configID='" />
                            			<xsl:value-of select="$conf" />
                        		</xsl:variable>
					<li>
					<xsl:if test="$thisTest[.=$coreTests]" >
                            			<xsl:value-of select="'** '" />
					</xsl:if>
                                	<a href="{$href}"> <xsl:value-of select="." /></a>
					<xsl:if test="$thisTest[.=$coreTests]" >
                            			<xsl:value-of select="' **'" />
					</xsl:if>
					</li>
				</xsl:for-each></ol>
			</xsl:if>
                        <xsl:if test="$numCrossFail>0">
				<xsl:value-of select="' ('" />
				<xsl:value-of select="$numCrossFail" />
				<xsl:value-of select="' cross-site)'" />
				<ol><xsl:for-each select="$crossFail">
					<xsl:sort select="."/>
                        		<xsl:variable name="href">
                            			<xsl:value-of select="'xslt.jsp?xsl=instance.xsl&amp;instanceID='" />
                            			<xsl:value-of select="instanceId" />
                            			<xsl:value-of select="'&amp;configID='" />
                            			<xsl:value-of select="seriesConfigId" />
                        		</xsl:variable>
					<li>
                                	  <a href="{$href}"><xsl:value-of select="replace(nickname, '^all2all:', '')" /></a>
					</li>
				</xsl:for-each></ol>
			</xsl:if>
                        <!--<xsl:if test="$numAllMiss>0">
                        	<u><b><xsl:value-of select="'Missing:'" /></b></u>
					<xsl:value-of select="' '" />
					<xsl:value-of select="$numAllMiss" /><br/>
				<ol><xsl:for-each select="$allMissing">
					<xsl:sort select="."/>
					<li><xsl:value-of select="."/></li>
				</xsl:for-each></ol>
			</xsl:if> -->
                    </td>
                </tr>
            </xsl:for-each>
        </table>
    </xsl:template>

</xsl:stylesheet>
